@@ -10,8 +10,10 @@
 #' @param height See details; only applicable if \code{x} is a \code{\link[tmap:tmap-element]{tmap}} object.
 #' @param res See details; only applicable if \code{x} is a \code{\link[tmap:tmap-element]{tmap}} object.
 #' @return aspect ratio
-#' @import sp
-#' @importFrom raster couldBeLonLat
+#' @importFrom grDevices colorRampPalette dev.off png rgb
+#' @importFrom methods as
+#' @importFrom stats aggregate na.omit
+#' @importFrom utils download.file
 #' @example ./examples/get_asp_ratio.R
 #' @export
 get_asp_ratio <- function(x, is.projected = NA, width=700, height=700, res=100) {
@@ -22,8 +24,9 @@ get_asp_ratio <- function(x, is.projected = NA, width=700, height=700, res=100)
 		dev.off()
 	} else {
 	    if (inherits(x, c("Spatial", "Raster", "sf", "sfc"))) {
+	        x <- to_sf_stars(x)
 	        bbx <- bb(x)
-	        if (is.na(is.projected)) is.projected <- is_projected(x)
+	        if (is.na(is.projected)) is.projected <- !sf::st_is_longlat(x)
 	    } else {
 	        bbx <- bb(x)
 	        if (is.na(is.projected)) is.projected <- !maybe_longlat(bbx)
